﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Interactivity;

namespace XDGGroupBySelectionCase
{
    public class GroupByCheckBoxBehavior : Behavior<CheckBox>
    {                     
        protected override void OnAttached()
        {
            base.OnAttached();
            AssociatedObject.PreviewMouseDown += AssociatedObject_PreviewMouseDown;
            AssociatedObject.Unchecked += AssociatedObject_Unchecked;
        }

        private void AssociatedObject_Unchecked(object sender, RoutedEventArgs e)
        {            
            GroupByRecord record = AssociatedObject.DataContext as GroupByRecord;
            if (record != null)
            {
                SetSelectionGroupBy(record, false);
            }
                AssociatedObject.Unchecked -= AssociatedObject_Unchecked;            
        }

        private void AssociatedObject_PreviewMouseDown(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            GroupByRecord record = AssociatedObject.DataContext as GroupByRecord;
            
            bool currentCheckState = (bool)record.Tag;
            bool newCheckState = !currentCheckState;            

            SetSelectionGroupBy(record, newCheckState);

            //Checks for parent check status.
            if (record.ParentRecord != null)
            {
                GroupByRecord parentGBR = record.ParentRecord as GroupByRecord;

                if (newCheckState)
                {
                    if (parentGBR.ChildRecords.Where(c => (bool)c.Tag == newCheckState).Count() == parentGBR.ChildRecords.Count)
                    {
                        parentGBR.Tag = newCheckState;
                    }
                }
                else
                {
                    parentGBR.Tag = newCheckState;
                }
            }

            e.Handled = true;
        }
  

        public void SetSelectionGroupBy(GroupByRecord record, bool isSelected)
        {
            record.Tag = isSelected;

            foreach(var x in record.ChildRecords)
            {
                if(x is GroupByRecord)
                {
                    GroupByRecord gbr = x as GroupByRecord;
                    gbr.Tag = isSelected;
                    SetSelectionGroupBy(gbr, isSelected);
                }
                else if(x is DataRecord)
                {
                    DataRecord dr = x as DataRecord;
                    SetSelectionDataRecord(dr, isSelected);
                }
                else
                {
                    return;
                }
            }
        }

        public void SetSelectionDataRecord(DataRecord record, bool isSelected)
        {
            record.IsSelected = isSelected;
        }
    }
}
